@@ -1,18 +1,25 @@
 import re
 import shlex
 from enum import Enum
+from typing import Dict, List
 
 from ipytv.exceptions import MalformedExtinfException
 
 
 class M3UEntry:
-    def __init__(self, url, name="", duration=-1):
+    def __init__(self, url: str, name: str = "", duration: str = "-1"):
         self.url = url
         self.name = name
         self.duration = str(duration)
 
-    def __eq__(self, other):
-        return self.url == other.url and self.name == other.name and self.duration == other.duration
+    def __eq__(self, other: object) -> bool:
+        return isinstance(other, M3UEntry) \
+               and self.url == other.url \
+               and self.name == other.name \
+               and self.duration == other.duration
+
+    def __ne__(self, other: object) -> bool:
+        return not self.__eq__(other)
 
 
 class IPTVAttr(Enum):
@@ -35,21 +42,19 @@ class IPTVChannel(M3UEntry):
     M3U_PLUS_EXTINF_REGEX = r'^#EXTINF:[-0-9\.]+(\s+[\w-]+="[^"]*")+,.*$'
     M3U_PLUS_EXTINF_PARSE_REGEX = r'^#EXTINF:(?P<duration_g>[-0-9\.]+)(?P<attributes_g>(\s+[\w-]+="[^"]*")*),(?P<name_g>.*)'
 
-    def __init__(self, url="", name="", duration=-1, attributes=None):
+    def __init__(self, url: str = "", name: str = "", duration: str = "-1", attributes: Dict = None):
         super().__init__(url, name, duration)
         self.attributes = attributes if attributes is not None else {}
 
-    def __eq__(self, other):
-        if isinstance(other, IPTVChannel) and \
-                super().__eq__(other) and \
-                self.attributes == other.attributes:
-            return True
-        return False
+    def __eq__(self, other: object) -> bool:
+        return isinstance(other, IPTVChannel) \
+               and super().__eq__(other) \
+               and self.attributes == other.attributes
 
-    def __ne__(self, other):
+    def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
 
-    def copy(self):
+    def copy(self) -> 'IPTVChannel':
         return IPTVChannel(
             url=self.url,
             name=self.name,
@@ -58,14 +63,14 @@ class IPTVChannel(M3UEntry):
         )
 
     @staticmethod
-    def is_m3u_extinf_string(extinf_string):
-        return re.search(IPTVChannel.M3U_EXTINF_REGEX, extinf_string)
+    def is_m3u_extinf_string(extinf_string: str) -> bool:
+        return re.search(IPTVChannel.M3U_EXTINF_REGEX, extinf_string) is not None
 
     @staticmethod
-    def is_m3u_plus_extinf_string(extinf_string):
-        return re.search(IPTVChannel.M3U_PLUS_EXTINF_REGEX, extinf_string)
+    def is_m3u_plus_extinf_string(extinf_string: str) -> bool:
+        return re.search(IPTVChannel.M3U_PLUS_EXTINF_REGEX, extinf_string) is not None
 
-    def parse_extinf_string(self, extinf_string):
+    def parse_extinf_string(self, extinf_string: str) -> None:
         m = re.match(IPTVChannel.M3U_PLUS_EXTINF_PARSE_REGEX, extinf_string)
         if m is None:
             raise MalformedExtinfException("Malformed EXTINF string:\n{}".format(extinf_string))
@@ -79,19 +84,19 @@ class IPTVChannel(M3UEntry):
         self.name = m.group("name_g")
 
     @staticmethod
-    def from_playlist_entry(entry):
+    def from_playlist_entry(entry: List) -> 'IPTVChannel':
         channel = IPTVChannel()
         for row in entry:
             if str(row).startswith('#EXTINF:'):
                 channel.parse_extinf_string(row)
             elif str(row).startswith('#'):
-                # a comment or an unsupported tag
+                # a comment or a non-supported tag
                 pass
             else:
                 channel.url = row
         return channel
 
-    def __str__(self):
+    def __str__(self) -> str:
         attr_str = ''
         if len(self.attributes) > 0:
             for attr in self.attributes:
